@@ -177,7 +177,11 @@ def inversion(input_file):
 
     em_specs = geophysical_systems.parameters()[input_param["system"]]
 
-    nThread = int(multiprocessing.cpu_count() / 2)
+    if "n_cpu" in input_param.keys():
+        n_cpu = int(input_param["n_cpu"])
+    else:
+        n_cpu = int(multiprocessing.cpu_count() / 2)
+
     lower_bound = input_param["lower_bound"][0]
     upper_bound = input_param["upper_bound"][0]
     chi_target = input_param["chi_factor"]
@@ -562,10 +566,10 @@ def inversion(input_file):
             con_object = workspace.get_entity(list(input_model.keys())[0])[0]
             con_model = con_object.get_data(list(input_model.values())[0])[0].values
 
-            if hasattr(con_object.parent, "centroids"):
-                grid = con_object.parent.centroids
+            if hasattr(con_object, "centroids"):
+                grid = con_object.centroids
             else:
-                grid = con_object.parent.vertices
+                grid = con_object.vertices
 
             tree = cKDTree(grid)
             _, ind = tree.query(np.vstack(model_vertices))
@@ -589,10 +593,10 @@ def inversion(input_file):
             con_object = workspace.get_entity(list(input_model.keys())[0])[0]
             con_model = con_object.get_data(list(input_model.values())[0])[0].values
 
-            if hasattr(con_object.parent, "centroids"):
-                grid = con_object.parent.centroids
+            if hasattr(con_object, "centroids"):
+                grid = con_object.centroids
             else:
-                grid = con_object.parent.vertices
+                grid = con_object.vertices
 
             tree = cKDTree(grid)
             _, ind = tree.query(np.vstack(model_vertices))
@@ -605,18 +609,18 @@ def inversion(input_file):
                 input_param["starting_model"]["value"]
             )
 
-    if "susceptibility" in list(input_param.keys()):
-        if "model" in list(input_param["susceptibility"].keys()):
+    if "susceptibility_model" in list(input_param.keys()):
+        if "model" in list(input_param["susceptibility_model"].keys()):
 
             input_model = input_param["susceptibility_model"]["model"]
             print(f"Interpolating susceptibility model {input_model}")
             sus_object = workspace.get_entity(list(input_model.keys())[0])[0]
             sus_model = sus_object.get_data(list(input_model.values())[0])[0].values
 
-            if hasattr(sus_object.parent, "centroids"):
-                grid = sus_object.parent.centroids
+            if hasattr(sus_object, "centroids"):
+                grid = sus_object.centroids
             else:
-                grid = sus_object.parent.vertices
+                grid = sus_object.vertices
 
             tree = cKDTree(grid)
             _, ind = tree.query(np.vstack(model_vertices))
@@ -787,7 +791,7 @@ def inversion(input_file):
                 sigmaMap=sigmaMap,
                 hz=hz_BFHS,
                 parallel=True,
-                n_cpu=nThread,
+                n_cpu=n_cpu,
                 verbose=False,
                 Solver=PardisoSolver,
             )
@@ -823,7 +827,7 @@ def inversion(input_file):
                 sigmaMap=sigmaMap,
                 hz=hz_BFHS,
                 parallel=True,
-                n_cpu=nThread,
+                n_cpu=n_cpu,
                 verbose=False,
                 Solver=PardisoSolver,
             )
@@ -904,7 +908,7 @@ def inversion(input_file):
             sigmaMap=mapping,
             hz=hz,
             parallel=True,
-            n_cpu=nThread,
+            n_cpu=n_cpu,
             Solver=PardisoSolver,
             chi=susceptibility,
         )
@@ -914,7 +918,7 @@ def inversion(input_file):
             sigmaMap=mapping,
             hz=hz,
             parallel=True,
-            n_cpu=nThread,
+            n_cpu=n_cpu,
             Solver=PardisoSolver,
         )
 
