@@ -2,7 +2,7 @@ import numpy as np
 from scipy.spatial import cKDTree
 from scipy.interpolate import LinearNDInterpolator
 import discretize
-from geoh5py.objects import BlockModel
+from geoh5py.objects import BlockModel, ObjectBase
 from geoh5py.workspace import Workspace
 from ipywidgets import (
     Dropdown,
@@ -303,15 +303,18 @@ class DataInterpolation(ObjectDataSelection):
 
         value = self.out_object.value
         self.out_object.options = self.objects.options
-        self.out_object.value = value
+        if value in self.out_object.options:
+            self.out_object.value = value
 
         value = self.xy_reference.value
         self.xy_reference.options = self.objects.options
-        self.xy_reference.value = value
+        if value in self.xy_reference.options:
+            self.xy_reference.value = value
 
         value = self.xy_extent.value
         self.xy_extent.options = self.objects.options
-        self.xy_extent.value = value
+        if value in self.xy_extent.options:
+            self.xy_extent.value = value
 
     def method_update(self, _):
         if self.method.value == "Inverse Distance":
@@ -332,7 +335,9 @@ class DataInterpolation(ObjectDataSelection):
 
     def interpolate_call(self):
 
-        object_from = self.workspace.get_entity(self.objects.value)[0]
+        for entity in self._workspace.get_entity(self.objects.value):
+            if isinstance(entity, ObjectBase):
+                object_from = entity
 
         if hasattr(object_from, "centroids"):
             xyz = object_from.centroids.copy()
@@ -346,7 +351,9 @@ class DataInterpolation(ObjectDataSelection):
 
         if self.out_mode.value == "To Object":
 
-            object_to = self.workspace.get_entity(self.out_object.value)[0]
+            for entity in self._workspace.get_entity(self.out_object.value):
+                if isinstance(entity, ObjectBase):
+                    object_to = entity
 
             if hasattr(object_to, "centroids"):
                 xyz_out = object_to.centroids.copy()
@@ -355,7 +362,9 @@ class DataInterpolation(ObjectDataSelection):
 
         else:
 
-            ref_in = self.workspace.get_entity(self.xy_reference.value)[0]
+            for entity in self._workspace.get_entity(self.xy_reference.value):
+                if isinstance(entity, ObjectBase):
+                    ref_in = entity
 
             if hasattr(ref_in, "centroids"):
                 xyz_ref = ref_in.centroids
@@ -372,6 +381,13 @@ class DataInterpolation(ObjectDataSelection):
             )
 
             # Use discretize to build a tensor mesh
+            delta_z = xyz_ref[:, 2].max() - xyz_ref[:, 2]
+            xyz_ref = xyz_ref[delta_z < self.depth_core.value, :]
+            depth_core = (
+                self.depth_core.value
+                - (xyz_ref[:, 2].max() - xyz_ref[:, 2].min())
+                + h[2]
+            )
             mesh = discretize.utils.meshutils.mesh_builder_xyz(
                 xyz_ref,
                 h,
@@ -380,16 +396,15 @@ class DataInterpolation(ObjectDataSelection):
                     [pads[2], pads[3]],
                     [pads[4], pads[5]],
                 ],
-                depth_core=self.depth_core.value,
+                depth_core=depth_core,
                 expansion_factor=self.expansion_fact.value,
             )
-
             object_to = BlockModel.create(
                 self.workspace,
                 origin=[mesh.x0[0], mesh.x0[1], xyz_ref[:, 2].max()],
                 u_cell_delimiters=mesh.vectorNx - mesh.x0[0],
                 v_cell_delimiters=mesh.vectorNy - mesh.x0[1],
-                z_cell_delimiters=-(xyz_ref[:, 2].max() - mesh.vectorNz[::-1]),
+                z_cell_delimiters=-(mesh.x0[2] + mesh.hz.sum() - mesh.vectorNz[::-1]),
                 name=self.new_grid.value,
             )
 
@@ -413,6 +428,8 @@ class DataInterpolation(ObjectDataSelection):
             if self.space.value == "Log":
                 sign[field] = np.sign(values[field])
                 values[field] = np.log(np.abs(values[field]))
+            else:
+                sign[field] = np.ones_like(values[field])
 
         values_interp = {}
         if self.method.value == "Linear":
@@ -420,7 +437,6 @@ class DataInterpolation(ObjectDataSelection):
             for key, value in values.items():
                 F = LinearNDInterpolator(xyz, value)
                 values_interp[key] = F(xyz_out)
-                sign[key] = np.ones_like(values_interp[key])
 
         elif self.method.value == "Inverse Distance":
 
@@ -496,7 +512,11 @@ class DataInterpolation(ObjectDataSelection):
         if self.topography.options.value == "Object" and self.workspace.get_entity(
             self.topography.objects.value
         ):
-            topo_obj = self.workspace.get_entity(self.topography.objects.value)[0]
+
+            for entity in self._workspace.get_entity(self.topography.objects.value):
+                if isinstance(entity, ObjectBase):
+                    topo_obj = entity
+
             if getattr(topo_obj, "vertices", None) is not None:
                 topo = topo_obj.vertices
             else:
@@ -528,7 +548,10 @@ class DataInterpolation(ObjectDataSelection):
         if self.xy_extent.value is not None and self.workspace.get_entity(
             self.xy_extent.value
         ):
-            xy_ref = self.workspace.get_entity(self.xy_extent.value)[0]
+
+            for entity in self._workspace.get_entity(self.xy_extent.objects.value):
+                if isinstance(entity, ObjectBase):
+                    xy_ref = entity
             if hasattr(xy_ref, "centroids"):
                 xy_ref = xy_ref.centroids
             elif hasattr(xy_ref, "vertices"):
